@@ -72,6 +72,8 @@ class Const(object):
     EXIT_CODE_SUCCESS = 0
     EXIT_CODE_GENERAL_ERROR = 1
     EXIT_CODE_INITIALIZATION_ERROR = 2
+    EXIT_CODE_DEBUG_PACKAGER_ROLLBACK_EXISTS = 101
+    EXIT_CODE_DEBUG_PACKAGER_ROLLBACK_MISSING = 102
 
 
 @util.export
